clc; close all;

% Declaring variables theta and phi
 syms theta;
 syms phi;

% Permittivity Value
e_r = 5;

% Permeability Value
u_r = 1;

% Replacing "j" with "1i" for robustness
j = 1i;

% Intrinsic Impedance of Free Space
Eta_Air = 377; 

% Speed of light in meters/second = c = 3 * 10^8 m/s
c = 3*10^8;

% Operational Frequency in GHz = 3 GHz
% Operational Frequency in Hz = 3 * 10^9 Hz
f_oper = 3*10^9;

% Operational Wavelength in meters = Speed of light/Operational Frequency
lambda_oper = c / f_oper;

% Wavenumber in free space
k = (2*pi)/(lambda_oper);

% Length of the patch in meters
L = (lambda_oper)/(2*sqrt(e_r * u_r));

% Width of the Patch in meters
W = 0.75*L;

% Thickness of the substrate in meters
d = ((lambda_oper)/(20*sqrt(e_r*u_r)));

% Value of "probe" radius for patch in meters
r = 0.01;

% Stationary expressions
k_x = (k).*sin(theta).*cos(phi);
k_y = (k).*sin(theta).*sin(phi);
k_z_1 = (k)*sqrt(((e_r)*(u_r))-((sin(theta)).^2));
k_z_2 = (k).*cos(theta);

% Msx
Ms_x = -d*2*(L^2)*k_x.*sin((k_y*W)/2).*exp((j*k_x*L)/2).*exp((j*k_y*W)/2).*cos((k_x*L)/2).*(1./((pi)^2 - (k_x*L).^2));     

% Msy
Ms_y = -d*2*W*k_x.*cos((k_x*L)/2).*exp((j*k_x*L)/2).*exp((j*k_y*W)/2).*sin((k_y*W)/2).*((k_y*W)/2);

% Tm and Te 
Tm = (e_r)*k_z_2.*cos(k_z_1*d)+(j.*k_z_1.*sin(k_z_1*d));
Te = k_z_1.*cos(k_z_1.*d)+(j.*k_z_2.*u_r.*sin(k_z_1*d));

% Calculating E_theta
E_theta_1 = j*k.*cos(theta).*(exp(-j*k*r))*(1/(2*pi*r)).*cos(k_z_1*d).*exp(j.*k_z_2*d);
E_theta_2 = (e_r).*k.*sin(phi).*(1./Tm).*Ms_x;
E_theta_3 = (e_r)*k.*cos(phi).*(1./Tm).*Ms_y;
E_theta = (E_theta_1).*((E_theta_2 - E_theta_3));

% Calculating E_Phi
E_phi_1 = j*k.*cos(theta).*(exp(-j*k*r))*(1/(2*pi*r)).*cos(k_z_1*d).*exp(j.*k_z_2*d);
E_phi_2 = k_z_1.*cos(phi).*(1./Te).*(Ms_x);
E_phi_3 = k_z_1.*sin(phi).*(1./Te).*(Ms_y);
E_phi = (E_phi_1).*(E_phi_2 + E_phi_3);

% Magnitude of E_theta
E_theta_conjugate = conj(E_theta);
E_theta_total = (E_theta.*E_theta_conjugate);

% Magnitude of E_phi
E_phi_conjugate = conj(E_phi);
E_phi_total = E_phi.*E_phi_conjugate;

% Taking the Real Part of E_theta and E_phi
E_Field_Total = real(E_theta_total+E_phi_total);

% Radiation Intensity Equation
U_Rad = (((r)^2)/(2*Eta_Air)).*E_Field_Total;

% Declaring Range for Theta to be from 0 radians to pi/2 radians
theta = 0:0.1:pi/2;

% The values for phi = 0 radians and pi/2 radianss
phi = [0 pi/2];

% Plotting the radiation intensity for the E-Plane and H-Plane
fplot(U_Rad,theta);